import os.path
import re
import nuke
import nukescripts

def get_pdplayer_path():

  if nuke.env['WIN32']:

    import _winreg

    path = 'C:\Program Files\Pdplayer\pdplayer.exe'

    try:
      k = _winreg.OpenKey( _winreg.HKEY_LOCAL_MACHINE, 'SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\pdplayer64.exe' )
    except EnvironmentError:

      try:
        k = _winreg.OpenKey( _winreg.HKEY_LOCAL_MACHINE, 'SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\pdplayer.exe' )
      except EnvironmentError:
        k = None

    if k:

      try:
        path = _winreg.QueryValue( k, None )
      except EnvironmentError:
        pass

      k.Close()
  
    return path

  elif nuke.env['MACOS']:
  
    return "/Applications/Pdplayer 64/MacOS/Pdplayer 64"
    
  else:
  
    return "/opt/pdplayer/pdplayer64"

class PdplayerFlipbook( nukescripts.FlipbookApplication ):

  def _append_fn( self, args, fn ):
    if nuke.env['WIN32']:
      args.append( "\"" + fn + "\"" )
    else:
      args.append( fn )

  def __init__( self ):
    self.path_ = get_pdplayer_path()

  def name( self ):
    return "Pdplayer"

  def path( self ):
    return self.path_

  def run( self, filename, frameRange, views, options ):

    range = "--range=" + str( frameRange.first() ) + "-" + str( frameRange.last() ) + "/" + str( frameRange.increment() )
    pa = "--pixel_aspect=" + str( options.get( "pixelAspect", 1 ) )

    os.path.normpath( filename )

    args = []
    self._append_fn( args, self.path() )

    if len( views ) > 1:

      (lfn, subs) = re.subn( "%V", views[0], filename );
      (lfn, subs) = re.subn( "%v", views[0][0], lfn );
      self._append_fn( args, lfn );
      args.append( range )
      args.append( pa )
      args.append( "--target_view=left" );

      (rfn, subs) = re.subn( "%V", views[1], filename );
      (rfn, subs) = re.subn( "%v", views[1][0], rfn );
      self._append_fn( args, rfn );
      args.append( range )
      args.append( pa )
      args.append( "--target_view=right" );

      args.append( "--stereo_view=both" )

    else:

      self._append_fn( args, filename );
      args.append( range )
      args.append( pa )

    os.spawnv( os.P_NOWAITO, self.path(), args )
  
  def capabilities( self ):
    return { 
      'proxyScale': False,
      'crop': False,
      'canPreLaunch': False,
      'supportsArbitraryChannels': False,
      'maximumViews' : 2,
      'fileTypes' : [ "exr", "mov", "tif", "tiff", "tga", "cin", "avi", "raw", "bmp", "gif", "jpg", "jpeg", "yuv", "pic", "rla", "dpx", "r3d", "png", "sgi", "rgb" ]
    }

nukescripts.register( PdplayerFlipbook() )
